# Readme

This script generates example truth and prediction segments
for sound event classification
and computes reference metrics using [sed-eval](https://github.com/TUT-ARG/sed_eval/).

The results are stored in this directory,
to prevent dependency issues with this package.

```bash
uv run event_based_reference.py
```
